exclude :test_edit_with_instance_method, 'needs further investigation'
exclude :test_edit_with_constant, 'needs further investigation'
exclude :test_edit_with_class_method, 'needs further investigation'
