exclude :test_execute_system_at_latest, "gem update --system was disabled by rubygems-integration"
exclude :test_execute_system_specific_older_than_minimum_supported_rubygems, "gem update --system was disabled by rubygems-integration"
exclude :test_execute_system_with_gems, "gem update --system was disabled by rubygems-integration"
exclude :test_execute_system, "gem update --system was disabled by rubygems-integration"
exclude :test_execute_system_multiple, "gem update --system was disabled by rubygems-integration"
exclude :test_execute_system_silent, "gem update --system was disabled by rubygems-integration"
exclude :test_execute_system_specific, "gem update --system was disabled by rubygems-integration"
exclude :test_execute_system_specific_newer_than_or_equal_to_3_2_leaves_plugins_dir_alone, "gem update --system was disabled by rubygems-integration"
exclude :test_execute_system_specific_older_than_3_2_removes_plugins_dir, "gem update --system was disabled by rubygems-integration"
exclude :test_execute_system_specifically_to_latest_version, "gem update --system was disabled by rubygems-integration"
exclude :test_execute_system_when_latest_does_not_support_your_ruby, "gem update --system was disabled by rubygems-integration"
exclude :test_execute_system_update_installed, "gem update --system was disabled by rubygems-integration"
exclude :test_execute_system_update_installed_in_non_default_gem_path, "gem update --system was disabled by rubygems-integration"
exclude :test_execute_system_when_latest_does_not_support_your_ruby_but_previous_one_does, "gem update --system was disabled by rubygems-integration"
