exclude :test_verify_security_policy_low_security, 'depends on source tree'
exclude :test_build_auto_signed_encrypted_key, 'depends on source tree'
exclude :test_verify_security_policy_checksum_missing, 'depends on source tree'
exclude :test_build_auto_signed, 'depends on source tree'
exclude :test_build_signed_encrypted_key, 'depends on source tree'
exclude :test_build_signed, 'depends on source tree'
