exclude :test_no_other_behavioral_changes_with_Kernel_warn, 'failure against ruby2.7, depends on source tree'
exclude :test_no_other_behavioral_changes_with_warn, 'failure against ruby2.7, depends on source tree'
exclude :test_no_kernel_require_in_warn_with_uplevel, 'failure against ruby2.7, depends on source tree'
exclude :test_no_kernel_require_in_Kernel_warn_with_uplevel, 'failure against ruby2.7, depends on source tree'
exclude :test_realworld_upgraded_default_gem, 'failure against ruby3.4, depends on source tree'
