exclude :test_error, 'fails, ENOTIME to investigate'
exclude :test_exit_in_fiber, 'fails, ENOTIME to investigate'
exclude :test_fork_from_fiber, 'fails, ENOTIME to investigate'
exclude :test_normal, 'fails, ENOTIME to investigate'
exclude :test_prohibit_resume_to_transferring_fiber, 'fails, ENOTIME to investigate'
exclude :test_prohibit_transfer_to_resuming_fiberhibit_transfer_to_resuming_fiber, 'fails, ENOTIME to investigate'
exclude :test_prohibit_transfer_to_resuming_fiber, 'fails, ENOTIME to investigate'
exclude :test_prohibit_transfer_to_yielding_fiberhibit_transfer_to_yielding_fiber, 'fails, ENOTIME to investigate'
exclude :test_prohibit_transfer_to_yielding_fiber, 'fails, ENOTIME to investigate'
exclude :test_raise_transferring_fiber, 'fails, ENOTIME to investigate'
exclude :test_resume_self, 'fails, ENOTIME to investigate'
exclude :test_return, 'fails, ENOTIME to investigate'
exclude :test_separate_lastline, 'fails, ENOTIME to investigate'
exclude :test_separate_lastmatch, 'fails, ENOTIME to investigate'
exclude :test_term, 'fails, ENOTIME to investigate'
exclude :test_terminate_transferred_fiber, 'fails, ENOTIME to investigate'
exclude :test_throw, 'fails, ENOTIME to investigate'
exclude :test_tls, 'fails, ENOTIME to investigate'
exclude :test_to_s, 'fails, ENOTIME to investigate'
exclude :test_transfer, 'fails, ENOTIME to investigate'
